@@ -16,7 +16,7 @@ utils::globalVariables(c(
   "hgTransformerGetEmbedding", "hgTransformerGetSentiment", "hgTransformerGetTextGeneration",
   "hgTransformerGetNER", "hgTransformerGetSummarization", "hgTransformerGetQA",
   "hgTransformerGetTranslation", "hgTokenizerGetTokens", "hgTransformerGetZeroShot",
-  "textModelsPy", "textModelsRMPy", "get_number_of_hidden_layers",
+  "textModelsPy", "textModelsRMPy", "get_number_of_hidden_layers", "hgTransformerFineTune",
 
 
   # EMBEDDINGS OBJECTS
@@ -33,6 +33,9 @@ utils::globalVariables(c(
   "data_train",
   "textTrainCVpredictions", "textTrainCVpredictionsRF",
 
+  # textPredcitTest
+  "stats_on_bootstrap",
+
   # Language Tasks
   "NamesNer",
   "no", "scores", # in textZeropShot
