@@ -53,6 +53,7 @@ select_eval_measure_val <- function(eval_measure = "bal_accuracy",
 #' Select evaluation measure and compute it (also used in logistic regression)
 #'
 #' @param outputlist_results_outer Results from outer predictions.
+#' @param id_nr ID numbers
 #' @return returns sorted predictions and truth, chi-square test, fisher test, and all evaluation metrics/measures
 #' @importFrom  tidyr unnest
 #' @importFrom  tibble is_tibble
@@ -82,16 +83,17 @@ classification_results <- function(outputlist_results_outer, id_nr = NA, ...) {
   fisher <- stats::fisher.test(predy_y$truth, predy_y$estimate)
 
 
-  accuracy <- yardstick::accuracy(predy_y, truth, estimate, ...)
+  accuracy     <- yardstick::accuracy(predy_y, truth, estimate, ...)
   bal_accuracy <- yardstick::bal_accuracy(predy_y, truth, estimate, ...)
-  sens <- yardstick::sens(predy_y, truth, estimate, ...)
-  spec <- yardstick::spec(predy_y, truth, estimate, ...)
-  precision <- yardstick::precision(predy_y, truth, estimate, ...)
-  kappa <- yardstick::kap(predy_y, truth, estimate, ...)
-  f_measure <- yardstick::f_meas(predy_y, truth, estimate, ...)
+  sens         <- yardstick::sens(predy_y, truth, estimate, ...)
+  spec         <- yardstick::spec(predy_y, truth, estimate, ...)
+  precision    <- yardstick::precision(predy_y, truth, estimate, ...)
+  kappa        <- yardstick::kap(predy_y, truth, estimate, ...)
+  f_measure    <- yardstick::f_meas(predy_y, truth, estimate, ...)
 
-  roc_auc <- yardstick::roc_auc(predy_y, truth, colnames(predy_y[3]))
+  roc_auc        <- yardstick::roc_auc(predy_y, truth, colnames(predy_y[3]))
   roc_curve_data <- yardstick::roc_curve(predy_y, truth, colnames(predy_y[3]))
+
   roc_curve_plot <- ggplot2::autoplot(yardstick::roc_curve(predy_y, truth, colnames(predy_y[3])))
 
   results_collected <- dplyr::bind_rows(
@@ -110,6 +112,70 @@ classification_results <- function(outputlist_results_outer, id_nr = NA, ...) {
   output
 }
 
+#' Select evaluation measure and compute it (also used in logistic regression)
+#'
+#' @param outputlist_results_outer Results from outer predictions.
+#' @param id_nr ID numbers
+#' @return returns sorted predictions and truth, chi-square test, fisher test, and all evaluation metrics/measures
+#' @importFrom  tidyr unnest
+#' @importFrom  tibble is_tibble
+#' @importFrom  dplyr full_join arrange bind_rows
+#' @importFrom  stats fisher.test
+#' @importFrom  yardstick accuracy bal_accuracy sens spec precision kap f_meas roc_auc rmse rsq
+#' @importFrom  ggplot2 autoplot
+#' @noRd
+classification_results_multi <- function(outputlist_results_outer, id_nr = NA, ...) {
+  predy_y <- tibble::tibble(
+    tidyr::unnest(outputlist_results_outer$truth, cols = c(truth)),
+    tidyr::unnest(outputlist_results_outer$estimate, cols = c(estimate)),
+    tidyr::unnest(outputlist_results_outer$id_nr, cols = c(id_nr))
+  )
+  for (i in 1:length(unique(levels(outputlist_results_outer$truth$truth[[1]]))))
+  {
+    predy_y[3+i]<-tibble::tibble(tidyr::unnest(outputlist_results_outer[[i]], cols = c(paste(".pred_", i, sep = ""))))
+  }
+
+  if (tibble::is_tibble(id_nr)) {
+    predy_y <- predy_y %>% dplyr::full_join(id_nr, by = "id_nr")
+  }
+
+  predy_y <- predy_y %>% dplyr::arrange(id_nr)
+  # Correlate predictions and observed help(all_of)
+
+  chisq <- suppressWarnings(chisq.test(table(predy_y$truth, predy_y$estimate)))
+
+  fisher <- stats::fisher.test(predy_y$truth, predy_y$estimate)
+
+
+  accuracy     <- yardstick::accuracy(predy_y, truth, estimate, ...)
+  bal_accuracy <- yardstick::bal_accuracy(predy_y, truth, estimate, ...)
+  sens         <- yardstick::sens(predy_y, truth, estimate, ...)
+  spec         <- yardstick::spec(predy_y, truth, estimate, ...)
+  precision    <- yardstick::precision(predy_y, truth, estimate, ...)
+  kappa        <- yardstick::kap(predy_y, truth, estimate, ...)
+  f_measure    <- yardstick::f_meas(predy_y, truth, estimate, ...)
+
+  roc_auc        <- yardstick::roc_auc(predy_y, truth, colnames(predy_y[4:(length(predy_y))]))
+  roc_curve_data <- yardstick::roc_curve(predy_y, truth, colnames(predy_y[4:(length(predy_y))]))
+
+  roc_curve_plot <- ggplot2::autoplot(yardstick::roc_curve(predy_y, truth, colnames(predy_y[4:(length(predy_y))])))
+
+  results_collected <- dplyr::bind_rows(
+    accuracy,
+    bal_accuracy,
+    sens,
+    spec,
+    precision,
+    kappa,
+    f_measure,
+    roc_auc
+  )
+
+  output <- list(predy_y, roc_curve_data, roc_curve_plot, fisher, chisq, results_collected)
+  names(output) <- c("predy_y", "roc_curve_data", "roc_curve_plot", "fisher", "chisq", "results_collected")
+  output
+}
+
 #' Function to fit a model and compute accuracy
 #'
 #' @param object An rsplit object (from results_nested_resampling tibble)
@@ -489,6 +555,7 @@ summarize_tune_results_rf <- function(object,
 #' @param x_append Variables to be appended after the word embeddings (x);
 #' if wanting to preappend them before the word embeddings use the option
 #' first = TRUE.  If not wanting to train with word embeddings, set x = NULL.
+#' @param append_first (boolean) Option to add variables before or after all word embeddings.
 #' @param cv_method Cross-validation method to use within a pipeline of nested outer and
 #' inner loops of folds (see nested_cv in rsample). Default is using cv_folds in the
 #' outside folds and "validation_split" using rsample::validation_split in the inner loop to
@@ -545,7 +612,7 @@ summarize_tune_results_rf <- function(object,
 #'   multi_cores = FALSE # This is FALSE due to CRAN testing and Windows machines.
 #' )
 #' }
-#' @seealso see \code{\link{textTrainLists}} \code{\link{textSimilarityTest}}
+#' @seealso see \code{\link{textTrainLists}}
 #' @importFrom stats cor.test na.omit chisq.test fisher.test complete.cases
 #' @importFrom dplyr select bind_cols starts_with filter arrange rename
 #' @importFrom tibble as_tibble
@@ -562,6 +629,7 @@ summarize_tune_results_rf <- function(object,
 textTrainRandomForest <- function(x,
                                   y,
                                   x_append = NULL,
+                                  append_first = FALSE,
                                   cv_method = "validation_split",
                                   outside_folds = 10,
                                   outside_strata_y = "y",
@@ -604,7 +672,10 @@ textTrainRandomForest <- function(x,
   }
 
   # sorting out x's
-  variables_and_names <- sorting_xs_and_x_append(x = x, x_append = x_append, ...)
+  variables_and_names <- sorting_xs_and_x_append(x = x,
+                                                 x_append = x_append,
+                                                 append_first = append_first,
+                                                 ...)
   x1 <- variables_and_names$x1
   x_name <- variables_and_names$x_name
   embedding_description <- variables_and_names$embedding_description
